<?php


class Cartstatusemail extends Tools_Plugins_Abstract {

    const DISPLAY_NAME = 'Email remarketing';
    const PRODUCT_RULE_ALL = 'all';
    const PRODUCT_RULE_ANY = 'any';
    const GATEWAY_QUOTE    = 'Quote';
    const CARTSTATUS_SECURE_TOKEN = 'CartStatus';

	protected $_dependsOn = array(
		'shopping'
	);

	protected function _init() {
		$missedPlugins = array_diff($this->_dependsOn, Tools_Plugins_Tools::getEnabledPlugins(true));

		if (!empty($missedPlugins)) {
			throw new Exceptions_SeotoasterPluginException('Required plugins should be enabled: <b>' . implode(',', $missedPlugins) . '</b>');
		}
        $this->_websiteConfig = Zend_Registry::get('website');

		$this->_view->setScriptPath(__DIR__ . '/system/views');
	}

    public function beforeController() {
        $this->_addCartStatusEmail();
    }

	public function merchandisingAction(){
		if (!Tools_Security_Acl::isAllowed(Shopping::RESOURCE_STORE_MANAGEMENT)){
			throw new Exceptions_SeotoasterPluginException('Forbidden');
		}
        $this->_view->websiteConfig = $this->_websiteConfig;
        $this->_view->mailTemplates = Application_Model_Mappers_TemplateMapper::getInstance()->findByType(Application_Model_Models_Template::TYPE_MAIL);

		echo $this->_view->render('merchandisingTab.phtml');
	}

    protected function _addCartStatusEmail(){
        $this->_injectContent($this->_view->render('cartStatusEmail.phtml'));
    }

    public function sendCartStatusEmailsAction(){
        if($this->_request->isPost()){
            $cacheHelper            = Zend_Controller_Action_HelperBroker::getExistingHelper('cache');
            $cartStatusQueueMapper  = Cartstatusemail_Models_Mapper_CartstatusemailQueueMapper::getInstance();
            if (null === ($cartStatusConfigData = $cacheHelper->load('cartstatus_configdata', 'cart_status'))){
                $settingsCartStatus     = Cartstatusemail_Models_Mapper_CartstatusemailSettingsMapper::getInstance()->fetchAll();
                $cartStatusDbtable      = new Cartstatusemail_Models_Dbtables_CartstatusemailSettingsDbtable();
                $cartStatusQueueModel   = new Cartstatusemail_Models_Models_CartstatusemailQueueModel();
                if(!empty($settingsCartStatus)){
                    foreach($settingsCartStatus as $statusCart){
                        $cartStatus     = $statusCart->getCartStatus();
                        $newCartStatus  = $statusCart->getCartStatus();
                        $periodHours    = $statusCart->getPeriodHours();
                        $productsIds    = $statusCart->getProductsIds();
                        $emailTemplate  = $statusCart->getEmailTemplate();
                        $emailFrom      = $statusCart->getEmailFrom();
                        $emailMessage   = $statusCart->getEmailMessage();
                        $productRule    = $statusCart->getProductsRule();
                        $productsIds    = explode(',', $productsIds);
                        $cartStatusId   = $statusCart->getId();
                        $where = '';
                        if(isset($cartStatus) && ($cartStatus == Models_Model_CartSession::CART_STATUS_PENDING || $cartStatus == Models_Model_CartSession::CART_STATUS_PROCESSING || $cartStatus == Models_Model_CartSession::CART_STATUS_CANCELED)){
                            $where = $cartStatusDbtable->getAdapter()->quoteInto('gateway <> ?', self::GATEWAY_QUOTE);
                        }
                        if(isset($cartStatus) && ($cartStatus == Tools_Misc::CS_ALIAS_PENDING)){
                            $cartStatus  = Models_Model_CartSession::CART_STATUS_PENDING;
                            $where = $cartStatusDbtable->getAdapter()->quoteInto('gateway = ?', self::GATEWAY_QUOTE);
                        }
                        if(isset($cartStatus) && $cartStatus == Tools_Misc::CS_ALIAS_PROCESSING){
                            $cartStatus  = Models_Model_CartSession::CART_STATUS_PROCESSING;
                            $where = $cartStatusDbtable->getAdapter()->quoteInto('gateway = ?', self::GATEWAY_QUOTE);
                        }
                        if(isset($cartStatus) && $cartStatus == Tools_Misc::CS_ALIAS_LOST_OPPORTUNITY){
                            $cartStatus  = Models_Model_CartSession::CART_STATUS_CANCELED;
                            $where = $cartStatusDbtable->getAdapter()->quoteInto('gateway = ?', self::GATEWAY_QUOTE);
                        }
                        if(strlen($where)>1){
                            $where .= ' AND '. $cartStatusDbtable->getAdapter()->quoteInto('status = ?', $cartStatus);
                        }else{
                            $where = $cartStatusDbtable->getAdapter()->quoteInto('status = ?', $cartStatus);
                        }
                        $limitPeriod = $periodHours+24;
                        $where .= " AND DATE_SUB(NOW(), INTERVAL $periodHours HOUR) > `updated_at`";
                        $where .= " AND DATE_SUB(NOW(), INTERVAL $limitPeriod HOUR) < `updated_at`";

                        if($productRule == self::PRODUCT_RULE_ALL || $productRule == self::PRODUCT_RULE_ANY){
                            $idsQuantity = count($productsIds);
                            if($idsQuantity > 1){
                                foreach($productsIds as $key => $ids){
                                    if($key == 0){
                                        $where .= ' AND ('. $cartStatusDbtable->getAdapter()->quoteInto('product_id = ?', $ids);
                                    }else{
                                        $where .= ' OR '. $cartStatusDbtable->getAdapter()->quoteInto('product_id = ?', $ids);
                                    }
                                }
                                $where .= ')';
                            }else{
                                $where .= ' AND '. $cartStatusDbtable->getAdapter()->quoteInto('product_id = ?', $productsIds[0]);
                            }
                        }

                        if($productRule == self::PRODUCT_RULE_ALL){
                            $select = $cartStatusDbtable->select()
                                ->setIntegrityCheck(false)
                                ->from(array('shcs' => 'shopping_cart_session'), array('shcs.id', 'cartCount' => 'count(shcs.id)'))
                                ->joinleft(array('shcsc' => 'shopping_cart_session_content'), 'shcs.id = shcsc.cart_id', array('cartId' => 'shcs.id'))
                                ->joinleft(array('u' => 'user'), 'shcs.user_id = u.id', array('userEmail' => 'u.email', 'userFullName' => 'u.full_name'))
                                ->where($where)->group('shcs.id')->having('cartCount > '.($idsQuantity-1));
                        }else{
                            $select = $cartStatusDbtable->select()
                                ->setIntegrityCheck(false)
                                ->from(array('shcs' => 'shopping_cart_session'), array('shcs.id', 'cartCount' => 'count(shcs.id)'))
                                ->joinleft(array('shcsc' => 'shopping_cart_session_content'), 'shcs.id = shcsc.cart_id', array('cartId' => 'shcs.id'))
                                ->joinleft(array('u' => 'user'), 'shcs.user_id = u.id', array('userEmail' => 'u.email', 'userFullName' => 'u.full_name'))
                                ->where($where)->group('shcs.id');
                        }
                        $resultCarts = $cartStatusDbtable->getAdapter()->fetchAssoc($select);
                        if(!empty($resultCarts)){
                            foreach($resultCarts as $cart){
                                $cartId     = $cart['cartId'];
                                $userEmail  = $cart['userEmail'];
                                if($userEmail != null){
                                    $emailQueueExist = $cartStatusQueueMapper->selectFromQueue($cartStatusId, $cartId, $userEmail);
                                    if(empty($emailQueueExist)){
                                        $cartStatusQueueModel->setCartId($cartId);
                                        $cartStatusQueueModel->setStatus(0);
                                        $cartStatusQueueModel->setCartStatusId($cartStatusId);
                                        $cartStatusQueueModel->setUserEmail($userEmail);
                                        $cartStatusQueueModel->setUserFullName($cart['userFullName']);
                                        $cartStatusQueueModel->setCartStatus($newCartStatus);
                                        $cartStatusQueueModel->setEmailMessage($emailMessage);
                                        $cartStatusQueueModel->setEmailFrom($emailFrom);
                                        $cartStatusQueueModel->setEmailTemplate($emailTemplate);
                                        $cartStatusQueueMapper->save($cartStatusQueueModel);
                                    }

                                }
                            }

                        }
                    }
                }
                $cartStatusConfigData = 1;
                $cacheHelper->save('cartstatus_configdata',  $cartStatusConfigData, 'cart_status', Helpers_Action_Cache::CACHE_SHORT);
                $this->_responseHelper->fail('');
            } elseif (!Tools_Security_Acl::isAllowed(Tools_Security_Acl::RESOURCE_CONTENT)){
                $emailsToSend = $cartStatusQueueMapper->getAllQueue();
                $selectActiveActionEmailTriggers = $cartStatusQueueMapper->getDbtable()->select()->setIntegrityCheck(false)->from('email_triggers_actions', array('trigger', 'id'));
                $activeActionEmailTriggers = $cartStatusQueueMapper->getDbTable()->getAdapter()->fetchAssoc($selectActiveActionEmailTriggers);
                if(!empty($emailsToSend)){
                    foreach($emailsToSend as $email){
                        $emailTriggerName = $this->_prepareEmailTriggerName($email->getCartStatus());
                        if (!array_key_exists($emailTriggerName, $activeActionEmailTriggers)) {
                            $this->_responseHelper->fail('missing action email trigger');
                        }
                        $email->registerObserver(new Tools_Mail_Watchdog(array(
                            'trigger' => $emailTriggerName
                        )));
                        $email->notifyObservers();
                    }
                    $this->_responseHelper->success('');
                }else{
                    $this->_responseHelper->fail('');
                }
            } else {
                $this->_responseHelper->fail('');
            }
        }
    }

    protected function _prepareEmailTriggerName($cartStatus){
        switch ($cartStatus) {
            case Models_Model_CartSession::CART_STATUS_NEW:
                $emailTriggerName = Cartstatusemail_Tools_CartstatusemailMailWatchdog::TRIGGER_CART_STATUS_ABANDONED;
                break;
            case Models_Model_CartSession::CART_STATUS_PENDING:
                $emailTriggerName = Cartstatusemail_Tools_CartstatusemailMailWatchdog::TRIGGER_CART_STATUS_ACTION_REQUIRE;
                break;
            case Models_Model_CartSession::CART_STATUS_PROCESSING:
                $emailTriggerName = Cartstatusemail_Tools_CartstatusemailMailWatchdog::TRIGGER_CART_STATUS_TECHNICAL_PROCESSING;
                break;
            case Models_Model_CartSession::CART_STATUS_COMPLETED:
                $emailTriggerName = Cartstatusemail_Tools_CartstatusemailMailWatchdog::TRIGGER_CART_STATUS_PAYMENT_RECEIVED;
                break;
            case Models_Model_CartSession::CART_STATUS_SHIPPED:
                $emailTriggerName = Cartstatusemail_Tools_CartstatusemailMailWatchdog::TRIGGER_CART_STATUS_ITEMS_SHIPPED;
                break;
            case Models_Model_CartSession::CART_STATUS_DELIVERED:
                $emailTriggerName = Cartstatusemail_Tools_CartstatusemailMailWatchdog::TRIGGER_CART_STATUS_ITEMS_DELIVERED;
                break;
            case Models_Model_CartSession::CART_STATUS_REFUNDED:
                $emailTriggerName = Cartstatusemail_Tools_CartstatusemailMailWatchdog::TRIGGER_CART_STATUS_REFUNDED_PURCHASE;
                break;
            case Tools_Misc::CS_ALIAS_PENDING:
                $emailTriggerName = Cartstatusemail_Tools_CartstatusemailMailWatchdog::TRIGGER_CART_STATUS_NEWQUOTE;
                break;
            case Tools_Misc::CS_ALIAS_PROCESSING:
                $emailTriggerName = Cartstatusemail_Tools_CartstatusemailMailWatchdog::TRIGGER_CART_STATUS_QUOTESENT;
                break;
            case Tools_Misc::CS_ALIAS_LOST_OPPORTUNITY:
                $emailTriggerName = Cartstatusemail_Tools_CartstatusemailMailWatchdog::TRIGGER_CART_STATUS_LOST_OPPORTUNITY;
                break;
            default:
                return false;
                break;
        }
        return $emailTriggerName;
    }

    public function cartRecoveryAction(){
        $code = filter_var($this->_request->getParam('code'),FILTER_SANITIZE_STRING);
        if ($code) {
            $codeArray = explode('_', $code);
            $hashKey = $codeArray[0];
            $cartId  = $codeArray[1];
            $cartStatusDbtable = new Cartstatusemail_Models_Dbtables_CartstatusemailSettingsDbtable();
            $productMapper = Models_Mapper_ProductMapper::getInstance();
            $cartSession = Tools_ShoppingCart::getInstance();
            $where = $cartStatusDbtable->getAdapter()->quoteInto('shcs.id=?',$cartId);
            $select = $cartStatusDbtable->select()
                ->setIntegrityCheck(false)
                ->from(array('shcs' => 'shopping_cart_session'))
                ->joinleft(array('u' => 'user'), 'shcs.user_id = u.id', array('registrationEmail' => 'u.email'))
                ->where($where)->group('shcs.id');
            $cartExist = $cartStatusDbtable->getAdapter()->fetchRow($select);
            if(!empty($cartExist)){
                $keyVerificationCode = md5($cartExist['registrationEmail'].$cartId);
                if($hashKey == $keyVerificationCode){
                    $cart    = Models_Mapper_CartSessionMapper::getInstance()->find($cartId);
                    if(!$cart instanceof Models_Model_CartSession) {
                        $this->_redirector->gotoUrl($this->_websiteUrl);
                    }
                    $cartSession->restoreCartSession($cartId);
                    $cartSession->setShippingAddressKey($cart->getShippingAddressId());
                    $cartSession->setBillingAddressKey($cart->getBillingAddressId());
                    $cartContent = $cartSession->getContent();
                    foreach ($cartContent as $key=>$product){
                        $productObject = $productMapper->find($product['product_id']);
                        if($productObject !== null){
                            $cartContent[$key]['photo']      = $productObject->getPhoto();
                        }
                    }
                    $cartSession->setContent($cartContent);
                    $cartSession->save();
                    $checkoutPage = Tools_Misc::getCheckoutPage();
                    if (!$checkoutPage instanceof Application_Model_Models_Page) {
                        throw new Exceptions_SeotoasterPluginException('Error rendering cart. Please select a checkout page');
                    }
                    $this->_redirector->gotoUrl($this->_websiteUrl . $checkoutPage->getUrl());
                }
            }
        }
        $this->_redirector->gotoUrl($this->_websiteUrl);


    }

}
